@@ -12,6 +12,9 @@ const (
 	NoPlatform               // Explicitly disable the feature
 	GitHubPlatform
 	GitLabPlatform
+	AzureDevOpsPlatform
+	GiteaPlatform
+	BitbucketPlatform
 	// TODO: Add others.
 )
 
@@ -21,6 +24,9 @@ func (p Platform) String() string {
 		"none",
 		"github",
 		"gitlab",
+		"azuredevops",
+		"gitea",
+		"bitbucket",
 	}[p]
 }
 
@@ -34,6 +40,12 @@ func PlatformFromString(s string) (Platform, error) {
 		return GitHubPlatform, nil
 	case "gitlab":
 		return GitLabPlatform, nil
+	case "azuredevops":
+		return AzureDevOpsPlatform, nil
+	case "gitea":
+		return GiteaPlatform, nil
+	case "bitbucket":
+		return BitbucketPlatform, nil
 	default:
 		return UnknownPlatform, fmt.Errorf("invalid scm platform value: %s", s)
 	}
